==> calligra_2.9.7.orig.tar.xz: calligra-2.9.7/stage/plugins/pageeffects/matrixwipe/parallelsnakes/KPrParallelSnakesWipeHorizontalStrategy.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Marijn Kruisselbrink <mkruisselbrink@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRPARALLELSNAKESWIPEHORIZONTALSTRATEGY_H
#define KPRPARALLELSNAKESWIPEHORIZONTALSTRATEGY_H

#include "../KPrMatrixWipeStrategy.h"

class KPrParallelSnakesWipeHorizontalStrategy : public KPrMatrixWipeStrategy
{
public:
    KPrParallelSnakesWipeHorizontalStrategy(bool reverseTop, bool reverseBottom, bool reverse);
    virtual ~KPrParallelSnakesWipeHorizontalStrategy();
protected:
    virtual int squareIndex(int x, int y, int columns, int rows);
    virtual Direction squareDirection(int x, int y, int columns, int rows);
    virtual int maxIndex(int columns, int rows);
private:
    bool m_reverseTop;
    bool m_reverseBottom;
};

#endif // KPRPARALLELSNAKESWIPEHORIZONTALSTRATEGY_H

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/plugins/pageeffects/matrixwipe/parallelsnakes/KPrParallelSnakesWipeHorizontalStrategy.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Marijn Kruisselbrink <mkruisselbrink@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRPARALLELSNAKESWIPEHORIZONTALSTRATEGY_H
#define KPRPARALLELSNAKESWIPEHORIZONTALSTRATEGY_H

#include "../KPrMatrixWipeStrategy.h"

class KPrParallelSnakesWipeHorizontalStrategy : public KPrMatrixWipeStrategy
{
public:
    KPrParallelSnakesWipeHorizontalStrategy(bool reverseTop, bool reverseBottom, bool reverse);
    ~KPrParallelSnakesWipeHorizontalStrategy() override;
protected:
    int squareIndex(int x, int y, int columns, int rows) override;
    Direction squareDirection(int x, int y, int columns, int rows) override;
    int maxIndex(int columns, int rows) override;
private:
    bool m_reverseTop;
    bool m_reverseBottom;
};

#endif // KPRPARALLELSNAKESWIPEHORIZONTALSTRATEGY_H
